@@ -23,7 +23,6 @@
  */
 
 #include "gchempaint-config.h"
-#include <math.h>
 #include "bondtool.h"
 #include "lib/settings.h"
 #include "lib/document.h"
@@ -33,6 +32,7 @@
 #include "lib/theme.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include <glib/gi18n-lib.h>
+#include <cmath>
 
 gcpBondTool::gcpBondTool (gcpApplication *App, string ToolId, unsigned nPoints): gcpTool (App, ToolId)
 {
@@ -499,7 +499,7 @@ void gcpBondTool::SetLength (double length)
 
 GtkWidget *gcpBondTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint/ui/bond.glade", "bond", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (GLADEDIR"/bond.glade", "bond", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_AngleBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-angle"));
